// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0-or-later

package negotiation

import (
	"sort"
	"testing"
)

func TestSpec(t *testing.T) {

	s := specs{
		spec{val: "text/plain", q: 0.9},
		spec{val: "text/html", q: 1.0},
		spec{val: "text/*", q: 0.7},
		spec{val: "text/*", q: 0.8},
	}

	sort.Sort(s)

	if s[0].val != "text/html" {
		t.Errorf("Expected text/html, got %s", s[0].val)
	}

	if s[1].val != "text/plain" {
		t.Errorf("Expected text/plain, got %s", s[1].val)
	}

	if s[2].val != "text/*" {
		t.Errorf("Expected text/*, got %s", s[2].val)
	}

	if s[3].val != "text/*" {
		t.Errorf("Expected text/*, got %s", s[3].val)
	}
}

func TestHasValue(t *testing.T) {

	s := specs{
		spec{val: "text/plain", q: 0.9},
		spec{val: "text/html", q: 1.0},
		spec{val: "text/*", q: 0.7},
		spec{val: "text/*", q: 0.8},
	}

	if !s.hasVal("text/plain") {
		t.Errorf("Expected true, got false")
	}

	if s.hasVal("text/xml") {
		t.Errorf("Expected false, got true")
	}
}
